import React, { useEffect } from 'react';
import { View } from 'react-native';
import Animated, { useAnimatedStyle, useSharedValue, withDelay, withRepeat, withSequence, withTiming } from 'react-native-reanimated';
const Loader = props => {
  const {
    size,
    animationDuration,
    color,
    spacing
  } = props;
  const dot_1 = useSharedValue(1);
  const dot_2 = useSharedValue(1);
  const dot_3 = useSharedValue(1);
  const circleColor = color ?? '#00b9fc';
  useEffect(() => {
    let d = animationDuration ?? 600;
    dot_1.value = withRepeat(withSequence(withTiming(1.3, {
      duration: d
    }), withTiming(1, {
      duration: d
    })), -1, true) ?? 1;
    dot_2.value = withRepeat(withDelay(d / 2, withSequence(withTiming(1.3, {
      duration: d
    }), withTiming(1, {
      duration: d
    }))), -1, true) ?? 1;
    dot_3.value = withRepeat(withDelay(d, withSequence(withTiming(1.3, {
      duration: d
    }), withTiming(1, {
      duration: d
    }))), -1, true) ?? 1;
  }, []);
  const animated_1 = useAnimatedStyle(() => ({
    transform: [{
      scale: dot_1.value
    }]
  }));
  const animated_2 = useAnimatedStyle(() => ({
    transform: [{
      scale: dot_2.value
    }]
  }));
  const animated_3 = useAnimatedStyle(() => ({
    transform: [{
      scale: dot_3.value
    }]
  }));
  const style = {
    width: size,
    height: size,
    marginHorizontal: spacing ?? 3,
    borderRadius: size / 2,
    backgroundColor: circleColor
  };
  return /*#__PURE__*/React.createElement(View, {
    style: {
      flexGrow: 0,
      flexDirection: 'row',
      alignItems: 'center',
      justifyContent: 'center'
    }
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: [style, animated_1]
  }), /*#__PURE__*/React.createElement(Animated.View, {
    style: [style, animated_2]
  }), /*#__PURE__*/React.createElement(Animated.View, {
    style: [style, animated_3]
  }));
};
export default Loader;
//# sourceMappingURL=index.js.map